<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform version="1.0"
   xmlns="http://www.w3.org/1999/xhtml"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:m="http://www.w3.org/1998/Math/MathML"
   xmlns:md="urn:publicid:IDN+mathdoc.org:schema:common:200312:en"
   xmlns:h="http://www.w3.org/1999/xhtml"
   xmlns:c="urn:publicid:IDN+mathdoc.org:schema:pseudocode:200312:en"
   xmlns:hfp="http://www.w3.org/2001/XMLSchema-hasFacetAndProperty"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns:xs="http://www.w3.org/2001/XMLSchema" 
   exclude-result-prefixes="md m h c hfp xsi xs"
>

<xsl:template match="md:procedure">
<div class="procedure">
<table><xsl:apply-templates/></table>
</div>
</xsl:template>

<xsl:template match="md:procedure/md:step">
<tr class="procedure-step">
<td class="procedure-step-label"><p class="step-label"><xsl:number count="md:step" format="1." level="single"/></p></td>
<td class="procedure-step">
<xsl:apply-templates/>
</td>
</tr>
</xsl:template>

<xsl:template match="md:definition-block">
<div class="definition-block">
<p class="definition-block-title">Definition <xsl:number count="md:definition-block" format="1:" level="any"/></p>
<div class="definition-block-contents">
<xsl:apply-templates/>
</div>
</div>
</xsl:template>

<xsl:template match="md:example">
<div class="example">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="md:comment">
<p class="comment">
Author Note: <xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="md:figure">
<div class="figure" id="{@id}">
<xsl:apply-templates select="graphic[@rendition='online']"/>
<p class="figure-title">Figure <xsl:number count="md:figure" format="1. " level="any"/><xsl:apply-templates select="title"/></p>
</div>
</xsl:template>

<xsl:template match="md:figure/title"><xsl:apply-templates/></xsl:template>

<xsl:template match="md:figure/graphic[@rendition='online']">
<p class="figure-image"><img src="{@src}"/></p>
</xsl:template>

<xsl:template match="md:algorithm">
<div class="algorithm">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="md:algorithm/title">
<p class="algorithm-title">Algorithm: <xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="md:algorithm/contents">
<div class="algorithm-contents">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="md:box">
<div class="box">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="md:box/title">
<p class="box-title"><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="md:box/contents">
<div class="box-contents">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="md:figure/label">
<xsl:param name="number"/>
<p class="figure-label">Figure <xsl:value-of select="$number"/>
<xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="md:citeref">
<xsl:variable name="to" select="@to"/>[<xsl:value-of select="count(//md:citations/*[@id=$to]/preceding-sibling::*)+1"/>]</xsl:template>

<xsl:template match="md:xref">
<a href="#{@to}">
<xsl:variable name="to" select="@to"/>
<xsl:variable name="target" select="local-name(//*[@id=$to])"/>
<xsl:choose>
<xsl:when test="$target='figure'">
<xsl:for-each select="//*[@id=$to]">
Figure <xsl:number count="md:figure" format="1." level="any"/>
</xsl:for-each>
</xsl:when>
<xsl:otherwise/>
</xsl:choose>
<xsl:apply-templates/>
</a>
</xsl:template>

<xsl:template match="md:inset">
<div class="inset">
<xsl:apply-templates/>
</div>
</xsl:template>

</xsl:transform>
