<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform version="1.0"
   xmlns="http://www.w3.org/1999/xhtml"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:m="http://www.w3.org/1998/Math/MathML"
   xmlns:mm="urn:publicid:IDN+mathdoc.org:schema:math:common:200312:en"
   xmlns:h="http://www.w3.org/1999/xhtml"
   xmlns:c="urn:publicid:IDN+mathdoc.org:schema:pseudocode:200312:en"
   xmlns:hfp="http://www.w3.org/2001/XMLSchema-hasFacetAndProperty"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns:xs="http://www.w3.org/2001/XMLSchema" 
   exclude-result-prefixes="mm m h c hfp xsi xs"
>

<xsl:template match="mm:tableau">
<table class="tableau">
<xsl:apply-templates/>
</table>
</xsl:template>

<xsl:template match="mm:tableau/row">
<xsl:variable name="class">
<xsl:choose>
<xsl:when test="not(preceding-sibling::*)">tableau-zeroth</xsl:when>
<xsl:when test="not(following-sibling::*)">tableau-lastrow</xsl:when>
<xsl:otherwise>tableau</xsl:otherwise>
</xsl:choose>
</xsl:variable>
<tr>
<xsl:for-each select="*">
<xsl:choose>
<xsl:when test="not(preceding-sibling::*)">
<td>
<xsl:attribute name="class"><xsl:value-of select="$class"/>-first</xsl:attribute>
<xsl:apply-templates select="."/>
</td>
</xsl:when>
<xsl:when test="not(following-sibling::*)">
<td>
<xsl:attribute name="class"><xsl:value-of select="$class"/>-last</xsl:attribute>
<xsl:apply-templates select="."/>
</td>
</xsl:when>
<xsl:otherwise>
<td>
<xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
<xsl:apply-templates select="."/>
</td>
</xsl:otherwise>
</xsl:choose>
</xsl:for-each>
</tr>
</xsl:template>

<xsl:template match="mm:refcopy">
<xsl:variable name="value" select="@to"/>
<xsl:apply-templates select="//mm:*[@id=$value]"></xsl:apply-templates>
</xsl:template>

<xsl:template match="mm:proof">
<div class="proof">
<p class="proof-label">Proof:</p>
<xsl:apply-templates/>
<p>&#x220e;</p>
</div>
</xsl:template>

<xsl:template match="mm:proof[@alternate=&#39;yes&#39;]">
<div class="proof">
<p><i>Alternate Proof:</i></p>
<xsl:apply-templates/>
<p>&#x220e;</p>
</div>
</xsl:template>

<xsl:template match="mm:solution">
<div class="solution">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="mm:nop"></xsl:template>

<xsl:template match="mm:equation">
<p class="equation">
<xsl:apply-templates/>
</p>
</xsl:template>

<xsl:template match="mm:equation/mm:side[following-sibling::mm:side]" priority="1">
<xsl:apply-templates/>
<xsl:text> = </xsl:text>
</xsl:template>

<xsl:template match="mm:equation/mm:side"><xsl:apply-templates/></xsl:template>

<xsl:template match="p/mm:derivation|mm:line/mm:derivation">
<xsl:apply-templates select="mm:line|line"/>
</xsl:template>

<xsl:template match="p/mm:derivation/mm:line|p/mm:derivation/line|mm:line/mm:derivation/mm:line|line/mm:derivation/line" priority="3">
<xsl:if test="preceding-sibling::mm:line or preceding-sibling::line">
<xsl:choose>
<xsl:when test="@operator">
<xsl:value-of select="@operator"/>
</xsl:when>
<xsl:otherwise>=</xsl:otherwise>
</xsl:choose>
</xsl:if>
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="mm:derivation">
<div class="derivation">
<table class="derivation">
<tr class="derivation">
<td class="derivation-left">
<xsl:apply-templates select="mm:line[1]|line[1]"/>
</td>
<td class="derivation-equals">
<xsl:choose>
<xsl:when test="mm:line[2]/attribute::operator or line[2]/attribute::operator">
<xsl:value-of select="mm:line[2]/@operator|line[2]/@operator"/>
</xsl:when>
<xsl:otherwise>=</xsl:otherwise>
</xsl:choose>
</td>
<td class="derivation-right">
<xsl:apply-templates select="mm:line[2]|line[2]"/>
</td>
</tr>
<xsl:apply-templates select="mm:line[2]/following-sibling::*|line[2]/following-sibling::*"/>
</table>
</div>
</xsl:template>

<xsl:template match="mm:derivation[@inline=&#39;yes&#39;]">
<div class="derivation">
<table class="derivation">
<tr class="derivation">
<xsl:for-each select="mm:line|line">
<xsl:if test="position()&#62;1">
<td class="derivation-equals">
<xsl:choose>
<xsl:when test="@operator">
<xsl:value-of select="@operator"/>
</xsl:when>
<xsl:otherwise>=</xsl:otherwise>
</xsl:choose>
</td>
</xsl:if>
<td class="derivation-right">
<xsl:apply-templates/>
</td>
</xsl:for-each>
</tr>
</table>
</div>
</xsl:template>

<xsl:template match="mm:derivation/mm:line[1]|mm:derivation/mm:line[2]|mm:derivation/line[1]|mm:derivation/line[2]" priority="2">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="mm:derivation/mm:line|mm:derivation/line">
<tr class="derivation">
<td>
</td>
<td class="derivation-equals">
<xsl:choose>
<xsl:when test="@operator">
<xsl:value-of select="@operator"/>
</xsl:when>
<xsl:otherwise>=</xsl:otherwise>
</xsl:choose>
</td>
<td class="derivation-right">
<xsl:apply-templates/>
</td>
</tr>
</xsl:template>

<xsl:template match="mm:theorem">
<div class="theorem">
<p><b>Theorem <xsl:number count="mm:theorem" format="1" level="any"/>:</b><xsl:text> </xsl:text><xsl:apply-templates></xsl:apply-templates></p></div>
</xsl:template>

<xsl:template match="mm:proposition">
<div class="proposition">
<p class="proposition-title">Proposition <xsl:number count="mm:proposition" format="1:" level="any"/></p>
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="mm:proposition/contents">
<div class="proposition-contents">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="mm:propositionref">
<xsl:variable name="to" select="@to"/>
Proposition 
<xsl:for-each select="//mm:proposition[@id=$to]">
<xsl:number count="mm:proposition" format="1" level="any"/>
</xsl:for-each>
</xsl:template>

<xsl:template match="mm:lemma">
<div class="theorem">
<p><b>Lemma <xsl:number count="mm:lemma" format="1" level="any"/>:</b><xsl:text> </xsl:text>
<xsl:apply-templates/>
</p>
</div>
</xsl:template>

<xsl:template match="mm:conjecture">
<div class="theorem">
<p><b>Conjecture <xsl:number count="mm:conjecture" format="1" level="any"/>:</b><xsl:text> </xsl:text>
<xsl:apply-templates/>
</p>
</div>
</xsl:template>

<xsl:template match="mm:corollary">
<div class="corollary">
<p><b>Corollary <xsl:number count="mm:corollary" format="1" level="any"/>:</b><xsl:text> </xsl:text>
<xsl:apply-templates/></p>
</div>
</xsl:template>


</xsl:transform>

