<?xml version="1.0" encoding="UTF-8" ?>

<!--
    Document   : md2mathml.xsl
    Created on : September 16, 2003, 4:39 PM
    Author     : alex
    Description:
        Purpose of transformation follows.
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:md="http://www.mathdoc.org/schemas/2003/MathDoc/Common"
   xmlns:m="http://www.w3.org/1998/Math/MathML"
   xmlns="http://www.w3.org/1998/Math/MathML"
   xmlns:c="http://www.mathdoc.org/schemas/2003/MathDoc/PseudoCode"
   xmlns:hfp="http://www.w3.org/2001/XMLSchema-hasFacetAndProperty"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns:xs="http://www.w3.org/2001/XMLSchema" 
   exclude-result-prefixes="md c hfp xsi xs"
>

<xsl:variable name="mathml-uri">http://www.w3.org/1998/Math/MathML</xsl:variable>
<xsl:variable name="common-uri">http://www.mathdoc.org/schemas/2003/MathDoc/Common</xsl:variable>
<!-- MathML rules -->

<!-- content markup to presentation markup -->
<xsl:template match="m:vector">
<mfenced>
<xsl:apply-templates/>
</mfenced>
</xsl:template>

<xsl:template match="m:matrix"  priority="2">
<mfenced open="[" close="]">
<mtable>
<xsl:apply-templates/>
</mtable>
</mfenced>
</xsl:template>

<xsl:template match="m:matrixrow"  priority="2">
<mtr>
<xsl:for-each select="*">
<mtd>
<xsl:apply-templates select="."/>
</mtd>
</xsl:for-each>
</mtr>
</xsl:template>


<xsl:template match="m:*">
  <xsl:element name="{local-name(.)}" namespace="{namespace-uri(.)}">
    <xsl:apply-templates select="@*|*|text()"/>
  </xsl:element>
</xsl:template>

<!-- Mathdoc translastions -->

<xsl:template match="md:def">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="md:index-of">
<math xmlns="http://www.w3.org/1998/Math/MathML">
<xsl:call-template name="mformat-index-of"/>
</math>
</xsl:template>

<xsl:template name="mformat-index-of">
<msub>
<mfenced>
<xsl:apply-templates/>
</mfenced>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="@suffix"/>
</xsl:call-template>
</msub>
</xsl:template>

<xsl:template match="md:min">
<math xmlns="http://www.w3.org/1998/Math/MathML">
<xsl:call-template name="mformat-min"/>
</math>
</xsl:template>

<xsl:template name="mformat-min">
<mrow>
<mtext>min</mtext>
<mfenced open="{{" close="}}">
<xsl:apply-templates/>
</mfenced>
</mrow>
</xsl:template>

<xsl:template match="md:argmin">
<math xmlns="http://www.w3.org/1998/Math/MathML">
<xsl:call-template name="mformat-argminmax">
<xsl:with-param name="argtype">argmin</xsl:with-param>
</xsl:call-template>
</math>
</xsl:template>

<xsl:template name="mformat-argminmax">
<xsl:param name="argtype"/>
<mrow>
<munder>
<mtext><xsl:value-of select="$argtype"/></mtext>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="@over"/>
</xsl:call-template>
</munder>
<mfenced open="{{" close="}}">
<xsl:apply-templates/>
</mfenced>
</mrow>
</xsl:template>

<xsl:template match="md:map">
<xsl:call-template name="mformat-map">
<xsl:with-param name="arrow">&#x2192;</xsl:with-param>
</xsl:call-template>
</xsl:template>

<xsl:template name="mformat-map">
<xsl:param name="arrow"/>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec"><xsl:value-of select="@name"/></xsl:with-param>
</xsl:call-template>
<mo>:</mo>
<xsl:apply-templates select="*[1]"/>
<mo><xsl:value-of select="$arrow"/></mo>
<xsl:apply-templates select="*[2]"/>
</xsl:template>

<xsl:template match="md:emap">
<xsl:call-template name="mformat-emap">
<xsl:with-param name="arrow">&#x21a6;</xsl:with-param>
</xsl:call-template>
</xsl:template>

<xsl:template name="mformat-emap">
<xsl:param name="arrow"/>
<xsl:apply-templates select="*[1]"/>
<mo><xsl:value-of select="$arrow"/></mo>
<xsl:apply-templates select="*[2]"/>
</xsl:template>


<xsl:template match="md:func">
<xsl:call-template name="mformat-func"/>
</xsl:template>

<xsl:template name="mformat-func">
<mrow>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="@name"/>
</xsl:call-template>
<mfenced>
<xsl:apply-templates/>
</mfenced>
</mrow>
</xsl:template>

<xsl:template match="md:st">
<xsl:choose>
<xsl:when test="@name">
<mrow><xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="@name"/>
</xsl:call-template>
<mtext> | </mtext><xsl:apply-templates/></mrow>
</xsl:when>
<xsl:otherwise>
<mo>|</mo><mrow><xsl:apply-templates/></mrow>
</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="md:set">
<xsl:call-template name="mformat-set"/>
</xsl:template>

<xsl:template name="mformat-set">
<mfenced open="{{" close="}}">
<xsl:apply-templates/>
</mfenced>
</xsl:template>

<!--
<xsl:template match="md:var">
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec"><xsl:value-of select="@name"/></xsl:with-param>
</xsl:call-template>
</xsl:template>
-->

<xsl:template name="mformat-variable">
<xsl:param name="spec"/>
<xsl:choose>
<!-- TODO: handle bang -->

<!-- TODO: handle more operators -->
<!--
<xsl:when test="contains($spec,',')">
<mrow>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-before($spec,',')"/>
</xsl:call-template>
<mo>,</mo>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,',')"/>
</xsl:call-template>
</mrow>
</xsl:when>

<xsl:when test="contains($spec,'+') and not(contains(substring-before($spec,'+'),'_') or contains(substring-before($spec,'+'),'^'))">
<mrow>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-before($spec,'+')"/>
</xsl:call-template>
<mo>+</mo>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'+')"/>
</xsl:call-template>
</mrow>
</xsl:when>

<xsl:when test="contains($spec,'/')">
<mrow>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-before($spec,'/')"/>
</xsl:call-template>
<mo>/</mo>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'/')"/>
</xsl:call-template>
</mrow>
</xsl:when>

<xsl:when test="contains($spec,'-')">
<mrow>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-before($spec,'-')"/>
</xsl:call-template>
<mo>-</mo>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'-')"/>
</xsl:call-template>
</mrow>
</xsl:when>

<xsl:when test="contains($spec,'&#x2219;')">
<mrow>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-before($spec,'&#x2219;')"/>
</xsl:call-template>
<mo>&#x2219;</mo>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'&#x2219;')"/>
</xsl:call-template>
</mrow>
</xsl:when>
-->
<xsl:when test="contains($spec,'_') and contains($spec,'^')">
<xsl:choose>
<!-- check for '_' in the exponent: implies exponent only-->
<xsl:when test="contains(substring-before($spec,'_'),'^')">
<msup>
<mi><xsl:value-of select="substring-before($spec,'^')"/></mi>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'^')"/>
</xsl:call-template>
</msup>
</xsl:when>
<!-- otherwise, we've got a suffix and then the exponent -->
<xsl:otherwise>
<msubsup>
<mi><xsl:value-of select="substring-before($spec,'_')"/></mi>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after(substring-before($spec,'^'),'_')"/>
</xsl:call-template>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'^')"/>
</xsl:call-template>
</msubsup>
</xsl:otherwise>
</xsl:choose>
</xsl:when>

<xsl:when test="contains($spec,'^')">
<msup>
<mi><xsl:value-of select="substring-before($spec,'^')"/></mi>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'^')"/>
</xsl:call-template>
</msup>
</xsl:when>

<xsl:when test="contains($spec,'_')">
<msub>
<mi><xsl:value-of select="substring-before($spec,'_')"/></mi>
<xsl:call-template name="mformat-variable">
<xsl:with-param name="spec" select="substring-after($spec,'_')"/>
</xsl:call-template>
</msub>
</xsl:when>

<xsl:otherwise><mi><xsl:value-of select="$spec"/></mi></xsl:otherwise>
</xsl:choose>

</xsl:template>

</xsl:stylesheet> 
