<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform version="1.0"
   xmlns="http://www.w3.org/1999/xhtml"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:p="urn:publicid:IDN+mathdoc.org:schema:paper:200312:en"
   xmlns:md="urn:publicid:IDN+mathdoc.org:schema:common:200312:en"
   xmlns:h="http://www.w3.org/1999/xhtml"
   xmlns:hfp="http://www.w3.org/2001/XMLSchema-hasFacetAndProperty"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns:xs="http://www.w3.org/2001/XMLSchema" 
   exclude-result-prefixes="p md h hfp xsi xs"
>

<xsl:import href="xhtml.xsl"/>
<xsl:import href="common2xhtml.xsl"/>
<xsl:import href="mathcommon2xhtml.xsl"/>
<xsl:import href="pseudocode2xhtml.xsl"/>
<xsl:import href="grammar2xhtml.xsl"/>

<xsl:import href="style.xsl"/>

<xsl:output doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0//EN"
            doctype-system="http://www.w3.org/TR/MathML2/dtd/xhtml-math11-f.dtd"
            encoding="ISO-8859-1"
            method="xml"/>

<xsl:template match="p:paper" xml:space='preserve'>
<html>
<head>
<xsl:apply-templates mode="head" select="title"/>
<xsl:call-template name="mathdoc-xhtml-style"/>
<xsl:apply-templates select="md:prolog/md:rendition[@type=&#39;xhtml&#39; or @type=&#39;html&#39;]/*"/>
</head>
<body bgcolor="#ffffff">
<xsl:apply-templates/>
</body>
</html>
</xsl:template>

<xsl:template match="p:paper/title" mode="head" xml:space='preserve'>
<title><xsl:apply-templates/></title>
</xsl:template>


<!-- prolog -->

<xsl:template match="md:prolog" xml:space='preserve'>
<div class="prolog">
<xsl:apply-templates select="title"></xsl:apply-templates>
<xsl:apply-templates select="author"/>

<xsl:if test="pubdate">
<p class="pubdate"><xsl:value-of select="pubdate"/></p>
</xsl:if>
<xsl:apply-templates select="abstract|acknowledgement"/>
</div>
</xsl:template>

<xsl:template match="p:paper/title">
<p class="title"><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="p:paper/subtitle">
<p class="subtitle"><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="md:prolog/author">
<xsl:choose>
<xsl:when test="email" xml:space='preserve'>
<p class="author"><a href="mailto:{email}"><xsl:value-of select="name"/></a></p>
</xsl:when>
<xsl:otherwise xml:space='preserve'>
<p class="author"><xsl:value-of select="name"/></p>
</xsl:otherwise>
</xsl:choose>
<xsl:apply-templates select="affiliation"/>
</xsl:template>

<xsl:template match="affiliation" xml:space='preserve'>
<div class="affiliation">
<xsl:apply-templates select="name" mode="affiliation"/>
<xsl:apply-templates select="address"/>
</div>
</xsl:template>

<xsl:template match="name" mode="affiliation">
<p class="affiliation-name"><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="address">
<xsl:apply-templates select="street"/>
<p class="affiliation-address"><xsl:value-of select="city"/>, <xsl:value-of select="state"/><xsl:text> </xsl:text><xsl:value-of select="zip"/></p>
</xsl:template>

<xsl:template match="street">
<xsl:apply-templates select="street"/>
<p class="affiliation-address"><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="md:prolog/abstract" xml:space='preserve'>
<div class="abstract">
<p class="abstract-title">ABSTRACT</p>
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="md:prolog/acknowledgement">
<div class="acknowledgement">
<p class="acknowledgement-title">Acknowledgements</p>
<xsl:apply-templates/>
</div>
</xsl:template>

<!-- body -->

<xsl:template match="p:section" xml:space='preserve'>
<div class="section" id="{@id}">
<p class="section-title-top"><xsl:number count="p:section" format="1.1." level="multiple"/><xsl:text> </xsl:text><xsl:value-of select="translate(title,&#39;abcdefghijklmnopqrstuvwxyz&#39;,&#39;ABCDEFGHIJKLMNOPQRSTUVWXYZ&#39;)"/>
</p>
<xsl:apply-templates select="contents|p:section"/>
</div>
</xsl:template>

<xsl:template match="p:section/p:section" xml:space='preserve'>
<div class="section" id="{@id}">
<p class="section-title-sub"><xsl:number count="p:section" format="1.1." level="multiple"/><xsl:text> </xsl:text><xsl:value-of select="title"/>
</p>
<xsl:apply-templates select="contents|p:section"/>
</div>
</xsl:template>

<xsl:template match="p:section/contents|p:appendix/contents" xml:space='preserve'>
<div class="contents">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="p:appendix" xml:space='preserve'>
<div class="section" id="{@id}">
<p class="section-title-top">
<xsl:number count="p:appendix" format="A." level="multiple"/><xsl:text> </xsl:text><xsl:value-of select="translate(title,&#39;abcdefghijklmnopqrstuvwxyz&#39;,&#39;ABCDEFGHIJKLMNOPQRSTUVWXYZ&#39;)"/>
</p>
<xsl:apply-templates select="contents|p:section"/>
</div>
</xsl:template>

<xsl:template match="p:appendix/p:section" xml:space='preserve'>
<div class="section" id="{@id}">
<!-- TODO: add appendix prefix to section headings -->
<p class="section-title-sub"><xsl:number count="p:appendix/p:section" format="1." level="multiple"/><xsl:text> </xsl:text><xsl:value-of select="title"/>
</p>
<xsl:apply-templates select="contents|p:section"/>
</div>
</xsl:template>

<xsl:template match="md:citations" xml:space='preserve'>
<div class="references">
<p class="section-title-top">REFERENCES</p>
<ol>
<xsl:apply-templates/>
</ol>
</div>
</xsl:template>

<xsl:template match="md:articleCitation" xml:space='preserve'>
<li><xsl:if test="authors"><xsl:apply-templates select="authors"/>, </xsl:if><i><xsl:value-of select="title"/></i>, <xsl:value-of select="month"/>/<xsl:value-of select="year"/> P. <xsl:value-of select="pages"/>
</li>
</xsl:template>

<xsl:template match="md:bookCitation" xml:space='preserve'>
<li><xsl:if test="authors"><xsl:apply-templates select="authors"/>, </xsl:if><i><xsl:value-of select="title"/></i>, <xsl:apply-templates select="address"/>, <xsl:value-of select="year"/>
</li>
</xsl:template>

<xsl:template match="md:bookCitation/address">
<xsl:value-of select="city"/>, <xsl:value-of select="state"/>
</xsl:template>

<xsl:template match="md:articleCitation/authors">
<xsl:apply-templates mode="citation"/>
</xsl:template>

<xsl:template match="md:bookCitation/authors">
<xsl:apply-templates mode="citation"/>
</xsl:template>

<xsl:template match="md:proceedingCitation/authors">
<xsl:apply-templates mode="citation"/>
</xsl:template>

<xsl:template match="author" mode="citation">
<xsl:apply-templates/>
<xsl:if test="following-sibling::author">, </xsl:if>
</xsl:template>

<!-- override common xref -->

<xsl:template match="md:xref">
<a href="#{@to}">
<xsl:variable name="to" select="@to"/>
<xsl:variable name="target" select="local-name(//*[@id=$to])"/>
<xsl:choose>
<xsl:when test="$target='figure'">
<xsl:for-each select="//*[@id=$to]">
Figure <xsl:number count="md:figure" format="1." level="any"/>
</xsl:for-each>
</xsl:when>
<xsl:when test="$target='section'">
<xsl:for-each select="//*[@id=$to]">
Section <xsl:number count="p:section" format="1.1." level="multiple"/>
</xsl:for-each>
</xsl:when>
<xsl:when test="$target='appendix'">
<xsl:for-each select="//*[@id=$to]">
Appendix <xsl:number count="p:appendix" format="A." level="multiple"/>
</xsl:for-each>
</xsl:when>
<xsl:otherwise/>
</xsl:choose>
<xsl:apply-templates/>
</a>
</xsl:template>

</xsl:transform>
