<?xml version='1.0'?>
<xsl:transform version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
   xmlns="http://www.w3.org/1999/xhtml" 
   xmlns:h="http://www.w3.org/1999/xhtml" 
   xmlns:ps="urn:publicid:IDN+mathdoc.org:schema:problemset:200312:en"
   xmlns:md="urn:publicid:IDN+mathdoc.org:schema:common:200312:en"
   xmlns:mm="urn:publicid:IDN+mathdoc.org:schema:math:common:200312:en"
   xmlns:c="urn:publicid:IDN+mathdoc.org:schema:pseudocode:200312:en"
   xmlns:hfp="http://www.w3.org/2001/XMLSchema-hasFacetAndProperty"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns:xs="http://www.w3.org/2001/XMLSchema" 
   exclude-result-prefixes="md ps h c hfp xsi xs"
>

<xsl:import href="xhtml.xsl"/>
<xsl:import href="common2xhtml.xsl"/>
<xsl:import href="mathcommon2xhtml.xsl"/>
<xsl:import href="pseudocode2xhtml.xsl"/>

<xsl:import href="style.xsl"/>

<xsl:output method="xml" encoding="ISO-8859-1" doctype-public="-//W3C//DTD XHTML 1.1 plus MathML 2.0//EN"  doctype-system="http://www.w3.org/TR/MathML2/dtd/xhtml-math11-f.dtd"/>

<xsl:template match="ps:problemset">
<html>
<head><xsl:apply-templates select="title" mode="head"/>
<!-- Crap for mathplayer... jerks
<object id="MathPlayer" classid="clsid:32F66A20-7614-11D4-BD11-00104BD3F987"><xsl:text> </xsl:text></object>
<xsl:processing-instruction name="import">namespace="m" implementation="#MathPlayer"</xsl:processing-instruction>
-->
<xsl:call-template name="mathdoc-xhtml-style"/>
<xsl:apply-templates select="md:prolog/md:rendition[@type='xhtml' or @type='html']/*"/>
</head>
<body bgcolor="#ffffff">
<xsl:apply-templates/>
</body>
</html>
</xsl:template>

<xsl:template match="ps:problemset/title" mode="head">
<title>Problem Set: <xsl:apply-templates/></title>
</xsl:template>

<!-- prolog -->
<xsl:template match="ps:problemset/title">
<p class="title">Problem Set: <xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="md:prolog">
<div class="prolog" xml:space='preserve'>
<table class="normal">
<tr>
<xsl:apply-templates select="author"/>
<xsl:apply-templates select="pubdate"/>
</tr>
</table>
</div>
</xsl:template>

<xsl:template match="pubdate">
<td><p class="pubdate"><xsl:apply-templates/></p></td>
</xsl:template>

<xsl:template match="author">
<xsl:apply-templates mode="author"/>
</xsl:template>

<xsl:template mode="author" match="name">
<td><p><b><xsl:apply-templates/></b></p></td>
</xsl:template>

<xsl:template mode="author" match="email">
<td><p><a class="author-email" href="mailto:{.}"><xsl:apply-templates/></a></p></td>
</xsl:template>


<!-- body -->

<xsl:template match="ps:problems" xml:space='preserve'>
<div class="problems">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="ps:problems/title">
<p class="problems-title"><xsl:number level="multiple" count="ps:problems" format="1.1."/><xsl:text> </xsl:text><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="ps:problem" xml:space='preserve'>
<div class="problem">
<p class="problem-title">Problem <xsl:number level="single" count="ps:problem" format="1"/></p>
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="ps:problem[label]" xml:space='preserve'>
<div class="problem">
<xsl:apply-templates/>
</div>
</xsl:template>


<xsl:template match="ps:problem/label">
<p class="problem-title">Problem <xsl:number level="single" count="ps:problem" format="1 - "/><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="md:intro">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="ps:problem/single-part" xml:space='preserve'>
<div class="part">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="ps:problem/part">
<div class="part"><xsl:text>
</xsl:text><table><tr><td><xsl:text>
</xsl:text>
<xsl:choose>
<xsl:when test="label">
<xsl:value-of select="label"/>
</xsl:when>
<xsl:otherwise>
<xsl:number level="single" count="part" format="(a)"/>
</xsl:otherwise>
</xsl:choose></td><td class="description"><xsl:apply-templates select="mm:description" mode="inline-description"/></td></tr></table>
<xsl:apply-templates select="mm:proof|mm:solution"/><xsl:text>
</xsl:text></div>
</xsl:template>

<xsl:template match="mm:description" xml:space='preserve'>
<div class="description">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template mode="inline-description" match="mm:description" xml:space='preserve'>
<xsl:apply-templates/>
</xsl:template>

</xsl:transform>
