<?xml version="1.0" encoding="UTF-8"?>
<xsl:transform version="1.0"
   xmlns="http://www.w3.org/1999/xhtml"
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:m="http://www.w3.org/1998/Math/MathML"
   xmlns:c="urn:publicid:IDN+mathdoc.org:schema:pseudocode:200312:en"
   xmlns:h="http://www.w3.org/1999/xhtml"
   xmlns:hfp="http://www.w3.org/2001/XMLSchema-hasFacetAndProperty"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
   xmlns:xs="http://www.w3.org/2001/XMLSchema" 
   exclude-result-prefixes="xsl m c h hfp xsi xs"
>

<xsl:output method="xml"/>

<xsl:template match="c:pseudocode">
<div class="pseudocode">
<p class="pseudo-main"><xsl:value-of select="@name"/>(<xsl:apply-templates select="args" mode="args"/>):</p>
<div class="pseudo-codeblock">
<xsl:apply-templates/>
</div>
</div>
</xsl:template>

<xsl:template mode="args" match="c:pseudocode/args">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="args/arg">
<xsl:if test="preceding-sibling::*">, </xsl:if><xsl:apply-templates/>
</xsl:template>

<xsl:template match="c:pseudocode/args"/>

<xsl:template match="c:do/c:varassign|c:pseudocode/c:varassign|c:if/then/c:varassign|c:if/else/c:varassign|c:if/else-if/then/c:varassign">
<p class="pseudo-statement"><xsl:apply-templates select="*[1]"/> &#x2190; <xsl:apply-templates select="*[2]"/></p>
</xsl:template>

<xsl:template match="c:varassign">
<xsl:apply-templates select="*[1]"/> &#x2190; <xsl:apply-templates select="*[2]"/>
</xsl:template>

<xsl:template match="c:alloc">
<p class="pseudo-statement"><span class="pseudo-keyword">allocate</span><xsl:text> </xsl:text><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="c:var"><xsl:apply-templates/></xsl:template>
<xsl:template match="c:avar"><xsl:apply-templates select="*[1]"/>[<xsl:apply-templates select="*[2]"/>]</xsl:template>

<xsl:template match="c:for">
<p class="pseudo-for"><span class="pseudo-keyword">for</span><xsl:text> </xsl:text><xsl:apply-templates select="*[1]"/><xsl:text> </xsl:text><xsl:apply-templates select="to"/> </p>
<xsl:apply-templates select="c:do"/>
</xsl:template>

<xsl:template match="c:for/to"><span class="pseudo-keyword">to</span><xsl:text> </xsl:text><xsl:apply-templates/></xsl:template>

<xsl:template match="c:while">
<p class="pseudo-while"><span class="pseudo-keyword">while</span><xsl:text> </xsl:text><xsl:apply-templates select="*[1]"/></p>
<xsl:apply-templates select="c:do"/>
</xsl:template>

<xsl:template match="c:do">
<p class="pseudo-do"><span class="pseudo-keyword">do</span></p>
<div class="pseudo-codeblock">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="c:repeat">
<p class="pseudo-repeat"><span class="pseudo-keyword">repeat</span></p>
<xsl:apply-templates select="c:do"/>
<p class="pseudo-until"><span class="pseudo-keyword">until</span><xsl:text> </xsl:text><xsl:apply-templates select="*[2]"/></p>
</xsl:template>

<xsl:template match="c:repeat/c:do">
<div class="pseudo-codeblock">
<xsl:apply-templates/>
</div>
</xsl:template>



<xsl:template match="c:fcall">
<p class="pseudo-statement"><xsl:value-of select="@name"/><xsl:text>(</xsl:text>
<xsl:for-each select="*">
<xsl:if test="preceding-sibling::*"><xsl:text>,</xsl:text></xsl:if>
<xsl:apply-templates select="."/>
</xsl:for-each>
<xsl:text>)</xsl:text>
</p>
</xsl:template>   

<xsl:template match="c:func"><xsl:value-of select="@name"/><xsl:text>(</xsl:text>
<xsl:for-each select="*">
<xsl:if test="preceding-sibling::*"><xsl:text>,</xsl:text></xsl:if>
<xsl:apply-templates select="."/>
</xsl:for-each>
<xsl:text>)</xsl:text>
</xsl:template>   

<xsl:template match="c:attr"><span class="pseudo-attribute"><xsl:value-of select="@name"/></span>[<xsl:apply-templates/>]</xsl:template>   

<xsl:template match="c:return">
<p class="pseudo-statement"><span class="pseudo-keyword">return</span><xsl:text> </xsl:text><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="c:if">
<p class="pseudo-if"><span class="pseudo-keyword">if</span><xsl:text> </xsl:text><xsl:apply-templates select="*[1]"/></p>
<xsl:apply-templates select="then|else-if|else"/>
</xsl:template>

<xsl:template match="c:if/then">
<p class="pseudo-then"><span class="pseudo-keyword">then</span></p>
<div class="pseudo-codeblock">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="c:if/else-if">
<p class="pseudo-else-if"><span class="pseudo-keyword">else if</span><xsl:text> </xsl:text><xsl:apply-templates select="*[1]"/></p>
<div class="pseudo-codeblock">
<xsl:apply-templates select="then"/>
</div>
</xsl:template>

<xsl:template match="c:if/else-if/then">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="c:if/else">
<p class="pseudo-else"><span class="pseudo-keyword">else</span></p>
<div class="pseudo-codeblock">
<xsl:apply-templates/>
</div>
</xsl:template>

<xsl:template match="c:cmp">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="c:cmp/op">
<xsl:text> </xsl:text><xsl:apply-templates/><xsl:text> </xsl:text>
</xsl:template>

<xsl:template match="c:exp">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="c:exp/c:exp">
<xsl:text>(</xsl:text>
<xsl:apply-templates/>
<xsl:text>)</xsl:text>
</xsl:template>


<xsl:template match="c:exp/op">
<xsl:text> </xsl:text><xsl:apply-templates/><xsl:text> </xsl:text>
</xsl:template>

<xsl:template match="c:constant">
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="c:comment">
<p class="pseudo-comment">// <xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="c:and">
<xsl:call-template name="pseudo-boolean-op">
<xsl:with-param name="operator">and</xsl:with-param>
</xsl:call-template>
</xsl:template>

<xsl:template match="c:and/c:and|c:or/c:and">(<xsl:call-template name="pseudo-boolean-op">
<xsl:with-param name="operator">and</xsl:with-param>
</xsl:call-template>)</xsl:template>

<xsl:template match="c:or">
<xsl:call-template name="pseudo-boolean-op">
<xsl:with-param name="operator">or</xsl:with-param>
</xsl:call-template>
</xsl:template>

<xsl:template match="c:and/c:or|c:or/c:or">(<xsl:call-template name="pseudo-boolean-op">
<xsl:with-param name="operator">or</xsl:with-param>
</xsl:call-template>)</xsl:template>


<xsl:template name="pseudo-boolean-op">
<xsl:param name="operator"/>
<xsl:for-each select="*">
<xsl:if test="preceding-sibling::*"><xsl:text> </xsl:text><xsl:value-of select="$operator"/><xsl:text> </xsl:text></xsl:if>
<xsl:apply-templates select="."/>
</xsl:for-each>
</xsl:template>



</xsl:transform> 

